@@ -47,7 +47,7 @@ UPLOAD_DATASET_RESUME_TEMPLATE = """
 *****************************************************************************
 """
 
-UPLOAD_SEGMENT_RESUME_TEMPLATE = """
+UPLOAD_SEGMENT_RESUME_TEMPLATE_SDK = """
 *****************************************************************************
  This upload action was interrupted.
  The draft number is %d.
@@ -59,6 +59,27 @@ UPLOAD_SEGMENT_RESUME_TEMPLATE = """
 *****************************************************************************
 """
 
+UPLOAD_SEGMENT_RESUME_TEMPLATE_CLI = """
+*****************************************************************************
+ This upload action was interrupted.
+ The draft number is %d.
+ To resume this upload and skip the uploaded files, please add '-s' option to
+ the previous command:
+
+     $ gas cp -s ...
+
+*****************************************************************************
+"""
+
+CACHE_SPACE_WARNING = """
+*****************************************************************************
+
+ %d bytes left on device, less than the dataset size %d bytes.
+ Please be aware that there is not enough space to cache the entire dataset.
+
+*****************************************************************************
+"""
+
 
 class RequestLogging:
     """This class used to lazy load request to logging.
