@@ -2,9 +2,12 @@
 #
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
-# pylint: disable=invalid-name, missing-module-docstring
+# pylint: disable=invalid-name
+
+"""Dataloader of VOC2012ActionClassification dataset."""
 
 import os
+from typing import Any
 
 from tensorbay.dataset import Data, Dataset
 from tensorbay.exception import ModuleImportError
@@ -52,22 +55,23 @@ def VOC2012ActionClassification(path: str) -> Dataset:
     for segment_name in _SEGMENT_NAMES:
         segment = dataset.create_segment(segment_name)
         with open(os.path.join(action_path, f"{segment_name}.txt"), encoding="utf-8") as fp:
-            for filename in fp:
-                filename = filename.strip()
-                segment.append(_get_data(filename, image_path, annotation_path))
+            for stem in fp:
+                stem = stem.strip()
+                segment.append(_get_data(stem, image_path, annotation_path))
     return dataset
 
 
-def _get_data(filename: str, image_path: str, annotation_path: str) -> Data:
+def _get_data(stem: str, image_path: str, annotation_path: str) -> Data:
     try:
         import xmltodict  # pylint: disable=import-outside-toplevel
     except ModuleNotFoundError as error:
         raise ModuleImportError(module_name=error.name) from error
-
-    data = Data(os.path.join(image_path, f"{filename}.jpg"))
+    data = Data(os.path.join(image_path, f"{stem}.jpg"))
     box2d = []
-    with open(os.path.join(annotation_path, f"{filename}.xml"), "r", encoding="utf-8") as fp:
-        objects = xmltodict.parse(fp.read())["annotation"]["object"]
+    with open(os.path.join(annotation_path, f"{stem}.xml"), "r", encoding="utf-8") as fp:
+        labels: Any = xmltodict.parse(fp.read())
+    objects = labels["annotation"]["object"]
+
     if not isinstance(objects, list):
         objects = [objects]
     for item in objects:
